@@ -126,7 +126,7 @@ class TypedAggregator:
             mask = updater.kwargs.get("mask")
             for cur_agg in agg._composite:
                 cur_agg = cur_agg[self.type]  # Hopefully works well enough
-                arg = expr.construct_output(dtype=cur_agg.return_type)
+                arg = expr.construct_output(cur_agg.return_type)
                 results.append(cur_agg._new(arg(mask=mask), expr, in_composite=True))
             final_expr = agg._finalize(*results)
             if expr.cfunc_name == "GrB_Matrix_reduce_Aggregator":
@@ -161,13 +161,13 @@ class TypedAggregator:
             A = expr.args[0]
             orig_updater = updater
             if agg._finalize is not None:
-                step1 = expr.construct_output(dtype=semiring.return_type)
+                step1 = expr.construct_output(semiring.return_type)
                 updater = step1(mask=updater.kwargs.get("mask"))
-            if expr.method_name == "reduce_columns":
+            if expr.method_name == "reduce_columnwise":
                 A = A.T
             size = A._ncols
             init = Vector.new(agg._initdtype, size=size)
-            init[:] = agg._initval  # O(1) dense vector in SuiteSparse 5
+            init[...] = agg._initval  # O(1) dense vector in SuiteSparse 5
             if agg._switch:
                 updater << semiring(init @ A.T)
             else:
@@ -181,7 +181,7 @@ class TypedAggregator:
             v = expr.args[0]
             step1 = Vector.new(semiring.return_type, size=1)
             init = Matrix.new(agg._initdtype, nrows=v._size, ncols=1)
-            init[:, :] = agg._initval  # O(1) dense column vector in SuiteSparse 5
+            init[...] = agg._initval  # O(1) dense column vector in SuiteSparse 5
             if agg._switch:
                 step1 << semiring(init.T @ v)
             else:
@@ -191,7 +191,7 @@ class TypedAggregator:
                 if step1.dtype == finalize.return_type:
                     step1 << finalize(step1)
                 else:
-                    step1 = finalize(step1).new(dtype=finalize.return_type)
+                    step1 = finalize(step1).new(finalize.return_type)
             if in_composite:
                 return step1
             expr = step1.reduce(_any)
@@ -205,14 +205,14 @@ class TypedAggregator:
             # This has not been benchmarked or optimized.
             # We may be able to intelligently choose the faster path.
             init1 = Vector.new(agg._initdtype, size=A._ncols)
-            init1[:] = agg._initval  # O(1) dense vector in SuiteSparse 5
+            init1[...] = agg._initval  # O(1) dense vector in SuiteSparse 5
             step1 = Vector.new(semiring.return_type, size=A._nrows)
             if agg._switch:
                 step1 << semiring(init1 @ A.T)
             else:
                 step1 << semiring(A @ init1)
             init2 = Matrix.new(agg._initdtype, nrows=A._nrows, ncols=1)
-            init2[:, :] = agg._initval  # O(1) dense vector in SuiteSparse 5
+            init2[...] = agg._initval  # O(1) dense vector in SuiteSparse 5
             semiring2 = agg._semiring2[semiring.return_type]
             step2 = Vector.new(semiring2.return_type, size=1)
             step2 << semiring2(step1 @ init2)
@@ -221,7 +221,7 @@ class TypedAggregator:
                 if step2.dtype == finalize.return_type:
                     step2 << finalize(step2)
                 else:
-                    step2 = finalize(step2).new(dtype=finalize.return_type)
+                    step2 = finalize(step2).new(finalize.return_type)
             if in_composite:
                 return step2
             expr = step2.reduce(_any)
@@ -419,8 +419,8 @@ def _argminmaxij(
 ):
     if expr.cfunc_name == "GrB_Matrix_reduce_Aggregator":
         A = expr.args[0]
-        if expr.method_name == "reduce_rows":
-            step1 = A.reduce_rows(monoid).new()
+        if expr.method_name == "reduce_rowwise":
+            step1 = A.reduce_rowwise(monoid).new()
 
             # i, j = step1.to_values()
             # D = Matrix.from_values(i, i, j, nrows=A._nrows, ncols=A._nrows)
@@ -429,12 +429,12 @@ def _argminmaxij(
             masked = semiring.any_eq(D @ A).new()
             masked(mask=masked.V, replace=True) << masked  # Could use select
             init = Vector.new(bool, size=A._ncols)
-            init[:] = False  # O(1) dense vector in SuiteSparse 5
+            init[...] = False  # O(1) dense vector in SuiteSparse 5
             updater << row_semiring(masked @ init)
             if in_composite:
                 return updater.parent
         else:
-            step1 = A.reduce_columns(monoid).new()
+            step1 = A.reduce_columnwise(monoid).new()
 
             # i, j = step1.to_values()
             # D = Matrix.from_values(i, i, j, nrows=A._ncols, ncols=A._ncols)
@@ -443,7 +443,7 @@ def _argminmaxij(
             masked = semiring.any_eq(A @ D).new()
             masked(mask=masked.V, replace=True) << masked  # Could use select
             init = Vector.new(bool, size=A._nrows)
-            init[:] = False  # O(1) dense vector in SuiteSparse 5
+            init[...] = False  # O(1) dense vector in SuiteSparse 5
             updater << col_semiring(init @ masked)
             if in_composite:
                 return updater.parent
@@ -453,7 +453,7 @@ def _argminmaxij(
         masked = binary.eq(v, step1).new()
         masked(mask=masked.V, replace=True) << masked  # Could use select
         init = Matrix.new(bool, nrows=v._size, ncols=1)
-        init[:, :] = False  # O(1) dense column vector in SuiteSparse 5
+        init[...] = False  # O(1) dense column vector in SuiteSparse 5
         step2 = col_semiring(masked @ init).new()
         if in_composite:
             return step2
@@ -467,7 +467,7 @@ def _argminmaxij(
 
 def _argminmax(agg, updater, expr, *, in_composite, monoid):
     if expr.cfunc_name == "GrB_Matrix_reduce_Aggregator":
-        if expr.method_name == "reduce_rows":
+        if expr.method_name == "reduce_rowwise":
             return _argminmaxij(
                 agg,
                 updater,
@@ -518,10 +518,10 @@ agg.argmax = Aggregator(
 def _first_last(agg, updater, expr, *, in_composite, semiring):
     if expr.cfunc_name == "GrB_Matrix_reduce_Aggregator":
         A = expr.args[0]
-        if expr.method_name == "reduce_columns":
+        if expr.method_name == "reduce_columnwise":
             A = A.T
         init = Vector.new(bool, size=A._ncols)
-        init[:] = False  # O(1) dense vector in SuiteSparse 5
+        init[...] = False  # O(1) dense vector in SuiteSparse 5
         step1 = semiring(A @ init).new()
         Is, Js = step1.to_values()
         # TODO: perform these loops in e.g. Cython
@@ -540,7 +540,7 @@ def _first_last(agg, updater, expr, *, in_composite, semiring):
     elif expr.cfunc_name.startswith("GrB_Vector_reduce"):
         v = expr.args[0]
         init = Matrix.new(bool, nrows=v._size, ncols=1)
-        init[:, :] = False  # O(1) dense matrix in SuiteSparse 5
+        init[...] = False  # O(1) dense matrix in SuiteSparse 5
         step1 = semiring(v @ init).new()
         index = step1[0].value
         if index is None:
@@ -551,10 +551,10 @@ def _first_last(agg, updater, expr, *, in_composite, semiring):
     else:  # GrB_Matrix_reduce
         A = expr.args[0]
         init1 = Matrix.new(bool, nrows=A._ncols, ncols=1)
-        init1[:, :] = False  # O(1) dense matrix in SuiteSparse 5
+        init1[...] = False  # O(1) dense matrix in SuiteSparse 5
         step1 = semiring(A @ init1).new()
         init2 = Vector.new(bool, size=A._nrows)
-        init2[:] = False  # O(1) dense vector in SuiteSparse 5
+        init2[...] = False  # O(1) dense vector in SuiteSparse 5
         step2 = semiring(step1.T @ init2).new()
         i = step2[0].value
         if i is None:
@@ -581,10 +581,10 @@ agg.last = Aggregator(
 def _first_last_index(agg, updater, expr, *, in_composite, semiring):
     if expr.cfunc_name == "GrB_Matrix_reduce_Aggregator":
         A = expr.args[0]
-        if expr.method_name == "reduce_columns":
+        if expr.method_name == "reduce_columnwise":
             A = A.T
         init = Vector.new(bool, size=A._ncols)
-        init[:] = False  # O(1) dense vector in SuiteSparse 5
+        init[...] = False  # O(1) dense vector in SuiteSparse 5
         expr = semiring(A @ init)
         updater << expr
         if in_composite:
@@ -592,7 +592,7 @@ def _first_last_index(agg, updater, expr, *, in_composite, semiring):
     elif expr.cfunc_name.startswith("GrB_Vector_reduce"):
         v = expr.args[0]
         init = Matrix.new(bool, nrows=v._size, ncols=1)
-        init[:, :] = False  # O(1) dense matrix in SuiteSparse 5
+        init[...] = False  # O(1) dense matrix in SuiteSparse 5
         step1 = semiring(v @ init).new()
         if in_composite:
             return step1
