@@ -8,7 +8,6 @@ from .exceptions import check_status
 from .expr import AmbiguousAssignOrExtract, Updater
 from .mask import Mask
 from .operator import UNKNOWN_OPCLASS, find_opclass, get_typed_op
-from .unary import identity
 from .utils import _Pointer, libget, output_type
 
 NULL = ffi.NULL
@@ -41,7 +40,14 @@ def call(cfunc_name, args):
             f" - C signature: {sig}\n"
             f" - Error: {exc}"
         )
-    rv = check_status(err_code, args)
+    try:
+        rv = check_status(err_code, args)
+    except Exception as exc:
+        # Record calls that fail for easier debugging
+        rec = _recorder.get(_prev_recorder)
+        if rec is not None:
+            rec.record(cfunc_name, args, exc=exc)
+        raise
     rec = _recorder.get(_prev_recorder)
     if rec is not None:
         rec.record(cfunc_name, args)
@@ -55,7 +61,7 @@ def _expect_type_message(
         if type(x) in types:
             return x, None
         elif output_type(x) in types:
-            if config["autocompute"]:
+            if config.get("autocompute"):
                 return x._get_value(), None
             extra_message = extra_message or f"{extra_message}\n\n"
             extra_message += (
@@ -65,7 +71,7 @@ def _expect_type_message(
     elif type(x) is types:
         return x, None
     elif output_type(x) is types:
-        if config["autocompute"]:
+        if config.get("autocompute"):
             return x._get_value(), None
         extra_message = extra_message or f"{extra_message}\n\n"
         extra_message += (
@@ -130,13 +136,17 @@ def _expect_op_message(
         elif "Monoid" in values:
             special_message = f"\nYou may do `{op.name}.monoid` to get the Monoid."
     elif op.opclass == "BinaryOp" and op.monoid is None and "Monoid" in values:
-        special_message = f"\nThe BinaryOp {op.name} is not known to be part of a Monoid."
+        special_message = f"\nThe BinaryOp {op.name} is not known to be part of a Monoid"
+        if op.parent.monoid is not None:
+            special_message += f" for {op.type} datatype."
+        else:
+            special_message += "."
     if extra_message:
         extra_message = f"\n{extra_message}"
     return (
         f"Bad type {argmsg}in {type(self).__name__}.{within}(...).\n"
         f"    - Expected type: {expected}.\n"
-        f"    - Got: {op.opclass} ({op.name})."
+        f"    - Got: {op.opclass} ({op})."
         f"{extra_message}"
         f"{special_message}"
     )
@@ -223,7 +233,7 @@ class BaseType:
             accum = accum_arg
         if accum is not None:
             # Normalize accumulator
-            accum = get_typed_op(accum, self.dtype)
+            accum = get_typed_op(accum, self.dtype, kind="binary")
             if accum.opclass == "Monoid":
                 accum = accum.binaryop
             else:
@@ -244,12 +254,6 @@ class BaseType:
 
         return _ewise_infix_expr(other, self, method="ewise_add", within="__ror__")
 
-    def __ior__(self, other):
-        raise TypeError(
-            f"Using __ior__ (e.g., x |= y) is not supported for type {type(self).__name__}."
-            "  To create an ewise_add expression using infix notation, do e.g. `op(x | y)`."
-        )
-
     def __and__(self, other):
         if self._is_scalar:
             return NotImplemented
@@ -264,12 +268,6 @@ class BaseType:
 
         return _ewise_infix_expr(self, other, method="ewise_mult", within="__rand__")
 
-    def __iand__(self, other):
-        raise TypeError(
-            f"Using __iand__ (e.g., x &= y) is not supported for type {type(self).__name__}."
-            "  To create an ewise_mult expression using infix notation, do e.g. `op(x & y)`."
-        )
-
     def __matmul__(self, other):
         if self._is_scalar:
             return NotImplemented
@@ -285,10 +283,10 @@ class BaseType:
         return _matmul_infix_expr(other, self, within="__rmatmul__")
 
     def __imatmul__(self, other):
-        raise TypeError(
-            f"Using __imatmul__ (e.g., x @= y) is not supported for type {type(self).__name__}."
-            "  To create an matmul expression using infix notation, do e.g. `semiring(x @ y)`."
-        )
+        if self._is_scalar:
+            raise TypeError("'__imatmul__' not supported for Scalar")
+        self << self @ other
+        return self
 
     def __bool__(self):
         raise TypeError(
@@ -316,7 +314,7 @@ class BaseType:
                             "Scalar accumulation with extract element"
                             "--such as `s(accum=accum) << v[0]`--is not supported"
                         )
-                    self.value = delayed.new(dtype=self.dtype, name="s_extract").value
+                    self.value = delayed.new(self.dtype, name="s_extract").value
                     return
 
                 # Extract (C << A[rows, cols])
@@ -338,7 +336,11 @@ class BaseType:
                     self.value = delayed.value
                     return
 
-                delayed = delayed.apply(identity)
+                # Two choices here: apply identity `delayed = delayed.apply(identity)`, or assign.
+                # Choose assign for now, since it works better for iso-valued objects.
+                # Perhaps we should benchmark to see which is faster and has less Python overhead.
+                self(mask=mask, accum=accum, replace=replace, input_mask=input_mask)[...] = delayed
+                return
             elif self._is_scalar:
                 if accum is not None:
                     raise TypeError(
@@ -392,9 +394,9 @@ class BaseType:
                                 "If you do wish to make a dense matrix, then please be explicit:"
                                 "\n\n    M[:, :] = s"
                             )
-                        updater[:, :] = scalar
+                        updater[...] = scalar
                     else:  # Vector
-                        updater[:] = scalar
+                        updater[...] = scalar
                     return
 
         if input_mask is not None:
@@ -508,12 +510,12 @@ class BaseExpression:
                 raise ValueError(f"No default expr_repr for len(args) == {len(args)}")
         self.expr_repr = expr_repr
         if dtype is None:
-            self.dtype = op.return_type
+            self.dtype = lookup_dtype(op.return_type)
         else:
             self.dtype = dtype
         self._value = None
 
-    def new(self, *, dtype=None, mask=None, name=None):
+    def new(self, dtype=None, *, mask=None, name=None):
         if (
             mask is None
             and self._value is not None
@@ -524,7 +526,7 @@ class BaseExpression:
                 rv.name = name
             self._value = None
             return rv
-        output = self.construct_output(dtype=dtype, name=name)
+        output = self.construct_output(dtype, name=name)
         if self.op is not None and self.op.opclass == "Aggregator":
             updater = output(mask=mask)
             self.op._new(updater, self)
