@@ -5,39 +5,38 @@ See list of numpy ufuncs supported by numpy here:
 https://numba.pydata.org/numba-doc/dev/reference/numpysupported.html#math-operations
 
 """
-import itertools
+import itertools as _itertools
 
-from .. import binary, monoid, operator
+from .. import binary as _binary
+from .. import monoid as _monoid
+from .. import operator as _operator
 from ..binary.numpy import _binary_names
 from ..monoid.numpy import _monoid_identities
 
 _semiring_names = {
     f"{monoid_name}_{binary_name}"
-    for monoid_name, binary_name in itertools.product(_monoid_identities, _binary_names)
+    for monoid_name, binary_name in _itertools.product(_monoid_identities, _binary_names)
 }
 
 # Remove incompatible combinations
 # <non-int>_<int>
 _semiring_names -= {
     f"{monoid_name}_{binary_name}"
-    for monoid_name, binary_name in itertools.product(
-        {"equal", "hypot", "logaddexp", "logaddexp2", "logical_and", "logical_or", "logical_xor"},
+    for monoid_name, binary_name in _itertools.product(
+        {"equal", "hypot", "logaddexp", "logaddexp2"},
         {"gcd", "lcm", "left_shift", "right_shift"},
     )
 }
 # <non-float>_<float>
 _semiring_names -= {
     f"{monoid_name}_{binary_name}"
-    for monoid_name, binary_name in itertools.product(
+    for monoid_name, binary_name in _itertools.product(
         {
             "bitwise_and",
             "bitwise_or",
             "bitwise_xor",
             "equal",
             "gcd",
-            "logical_and",
-            "logical_or",
-            "logical_xor",
         },
         {
             "arctan2",
@@ -55,7 +54,7 @@ _semiring_names -= {
 # <float>_<non-float>
 _semiring_names -= {
     f"{monoid_name}_{binary_name}"
-    for monoid_name, binary_name in itertools.product(
+    for monoid_name, binary_name in _itertools.product(
         {"hypot", "logaddexp", "logaddexp2"},
         {"bitwise_and", "bitwise_or", "bitwise_xor"},
     )
@@ -63,15 +62,15 @@ _semiring_names -= {
 # <bool>_<non-bool>
 _semiring_names -= {
     f"{monoid_name}_{binary_name}"
-    for monoid_name, binary_name in itertools.product(
-        {"equal", "logical_and", "logical_or", "logical_xor"},
+    for monoid_name, binary_name in _itertools.product(
+        {"equal"},
         {"floor_divide", "fmod", "mod", "power", "remainder", "subtract"},
     )
 }
 # <non-bool>_<bool>
 _semiring_names -= {
     f"{monoid_name}_{binary_name}"
-    for monoid_name, binary_name in itertools.product(
+    for monoid_name, binary_name in _itertools.product(
         {"gcd", "hypot", "logaddexp", "logaddexp2"},
         {
             "equal",
@@ -79,9 +78,6 @@ _semiring_names -= {
             "greater_equal",
             "less",
             "less_equal",
-            "logical_and",
-            "logical_or",
-            "logical_xor",
             "not_equal",
         },
     )
@@ -97,16 +93,16 @@ def __getattr__(name):
     if name not in _semiring_names:
         raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
     words = name.split("_")
-    for i in range(1, len(words)):
+    for i in range(1, len(words)):  # pragma: no branch
         monoid_name = "_".join(words[:i])
-        if not hasattr(monoid.numpy, monoid_name):
+        if not hasattr(_monoid.numpy, monoid_name):
             continue
         binary_name = "_".join(words[i:])
-        if hasattr(binary.numpy, binary_name):
+        if hasattr(_binary.numpy, binary_name):  # pragma: no branch
             break
-    operator.Semiring.register_new(
-        f"numpy.{name}",
-        getattr(monoid.numpy, monoid_name),
-        getattr(binary.numpy, binary_name),
+    _operator.get_semiring(
+        getattr(_monoid.numpy, monoid_name),
+        getattr(_binary.numpy, binary_name),
+        name=f"numpy.{name}",
     )
     return globals()[name]
