@@ -6,6 +6,7 @@ from grblas import binary, dtypes, monoid, operator, semiring, unary
 BOOL = frozenset({"BOOL"})
 UINT = frozenset({"UINT8", "UINT16", "UINT32", "UINT64"})
 INT = frozenset({"INT8", "INT16", "INT32", "INT64", "UINT8", "UINT16", "UINT32", "UINT64"})
+BOOLINT = frozenset(BOOL | INT)
 FP = frozenset({"FP32", "FP64"})
 FPINT = frozenset(FP | INT)
 NOFC = frozenset(BOOL | FPINT)
@@ -42,17 +43,18 @@ BINARY = {
         "rminus", "second", "times",
     },
     (ALL, BOOL): {"eq", "ne"},
-    (ALL, FP): {"truediv"},
-    (ALL, NOFC): {"absfirst"},
+    (ALL, FCFP): {"truediv", "rtruediv"},
+    (ALL, NOFC): {"absfirst", "abssecond"},
     (ALL, POS): {
         "firsti", "firsti1", "firstj", "firstj1", "secondi", "secondi1", "secondj", "secondj1",
     },
+    (BOOLINT, FP): {"ldexp"},
     (INT, INT): {"band", "bclr", "bget", "bor", "bset", "bshift", "bxnor", "bxor"},
-    (NOFC, BOOL): {"ge", "gt", "land", "le", "lor", "lt", "lxnor", "lxor"},
+    (NOFC, BOOL): {"ge", "gt", "le", "lt", "lxnor"},
     (NOFC, FC): {"cmplx"},
-    (NOFC, FP): {"atan2", "copysign", "fmod", "hypot", "ldexp", "remainder"},
-    (NOFC, FPINT): {"floordiv"},
-    (NOFC, NOFC): {"isge", "isgt", "isle", "islt", "max", "min"},
+    (NOFC, FP): {"atan2", "copysign", "fmod", "hypot", "remainder"},
+    (NOFC, FPINT): {"floordiv", "rfloordiv"},
+    (NOFC, NOFC): {"isge", "isgt", "isle", "islt", "land", "lor", "lxor", "max", "min"},
 }
 MONOID = {
     (UINT, UINT): {"band", "bor", "bxnor", "bxor"},
@@ -68,13 +70,13 @@ _SEMIRING1 = {
         {"any"},
         {"first", "pair", "second"},
     ],
-    (ALL, FP): [
-        {"any", "max", "min", "plus", "times"},
+    (ALL, FCFP): [
+        {"any", "plus", "times"},
         {"truediv"},
     ],
     (ALL, NOFC): [
         {"max"},
-        {"absfirst"},
+        {"absfirst", "abssecond"},
     ],
     (ALL, POS): [  # POS, extra->INT64
         {"any", "max", "min", "plus", "times"},
@@ -89,6 +91,10 @@ _SEMIRING1 = {
         {"any", "eq", "land", "lor", "lxnor", "lxor"},
         {"eq", "land", "lor", "lxor", "ne", "ge", "gt", "le", "lt"},
     ],
+    (NOFC, FP): [
+        {"max", "min"},
+        {"truediv"},
+    ],
     (FPINT, FPINT): [
         # Some of these are superseded by (ALL, ALL)
         # We could cast BOOL to INT8
@@ -110,7 +116,7 @@ _SEMIRING1 = {
     ],
     (NOBOOL, FPINT): [
         {"plus"},
-        {"absfirst"},
+        {"absfirst", "abssecond"},
     ],
     (NOFC, FPINT): [
         {"any", "max", "min", "plus", "times"},
@@ -135,6 +141,8 @@ SEMIRING = defaultdict(set)
 for name, (ins, outs) in _SEMIRING2.items():
     SEMIRING[(frozenset(ins), frozenset(outs))].add(name)
 IGNORE = {
+    # Created by
+    "plus_copysign",
     # UDFs created during tests
     "is_positive",
     "plus_one",
@@ -145,6 +153,119 @@ IGNORE = {
     "myplus",
     "plus_myplus",
     "plus_numpy_copysign",
+    # Semirings created by commutation
+    "any_rfloordiv",
+    "any_rtruediv",
+    "max_abssecond",
+    "max_rfloordiv",
+    "max_rtruediv",
+    "min_rfloordiv",
+    "min_rtruediv",
+    "plus_abssecond",
+    "plus_rfloordiv",
+    "plus_rtruediv",
+    "times_rfloordiv",
+    "times_rtruediv",
+    # numpy-graphblas commutation (can we clean this up?)
+    "band_land",
+    "band_lor",
+    "band_lxor",
+    "band_max",
+    "band_min",
+    "band_minus",
+    "band_plus",
+    "band_pow",
+    "band_times",
+    "bor_land",
+    "bor_lor",
+    "bor_lxor",
+    "bor_max",
+    "bor_min",
+    "bor_minus",
+    "bor_plus",
+    "bor_pow",
+    "bor_times",
+    "bxor_land",
+    "bxor_lor",
+    "bxor_lxor",
+    "bxor_max",
+    "bxor_min",
+    "bxor_minus",
+    "bxor_plus",
+    "bxor_pow",
+    "bxor_times",
+    "eq_max",
+    "eq_min",
+    "eq_plus",
+    "eq_times",
+    "land_max",
+    "land_min",
+    "land_minus",
+    "land_plus",
+    "land_pow",
+    "land_times",
+    "lor_max",
+    "lor_min",
+    "lor_minus",
+    "lor_plus",
+    "lor_pow",
+    "lor_times",
+    "lxor_max",
+    "lxor_min",
+    "lxor_minus",
+    "lxor_plus",
+    "lxor_pow",
+    "lxor_times",
+    "max_atan2",
+    "max_band",
+    "max_bor",
+    "max_bxor",
+    "max_copysign",
+    "max_eq",
+    "max_ge",
+    "max_gt",
+    "max_ldexp",
+    "max_le",
+    "max_lt",
+    "max_ne",
+    "max_pow",
+    "min_atan2",
+    "min_band",
+    "min_bor",
+    "min_bxor",
+    "min_copysign",
+    "min_eq",
+    "min_ge",
+    "min_gt",
+    "min_ldexp",
+    "min_le",
+    "min_lt",
+    "min_ne",
+    "min_pow",
+    "plus_atan2",
+    "plus_band",
+    "plus_bor",
+    "plus_bxor",
+    "plus_ldexp",
+    "times_atan2",
+    "times_band",
+    "times_bor",
+    "times_bxor",
+    "times_copysign",
+    "times_eq",
+    "times_ge",
+    "times_gt",
+    "times_ldexp",
+    "times_le",
+    "times_lt",
+    "times_ne",
+    "times_pow",
+    "band_rminus",
+    "bor_rminus",
+    "bxor_rminus",
+    "land_rminus",
+    "lor_rminus",
+    "lxor_rminus",
 }
 
 
