@@ -269,12 +269,26 @@ def test_neg():
             assert (-empty).value is None
 
 
+def test_invert():
+    empty = Scalar.new(bool)
+    assert empty == ~empty
+    assert (~empty).value is None
+    not_s = Scalar.from_value(0, dtype=bool)
+    s = Scalar.from_value(1, dtype=bool)
+    assert ~s == not_s
+    assert (~s).value == not_s.value
+    assert not (s.value) == not_s.value
+    bad = Scalar.new(int)
+    with pytest.raises(TypeError, match="The invert operator"):
+        ~bad
+
+
 def test_wait(s):
     s.wait()
 
 
 @autocompute
-def test_expr_is_like_vector(s):
+def test_expr_is_like_scalar(s):
     v = grblas.Vector.from_values([1], [2])
     attrs = {attr for attr, val in inspect.getmembers(s)}
     expr_attrs = {attr for attr, val in inspect.getmembers(v.inner(v))}
@@ -282,6 +296,7 @@ def test_expr_is_like_vector(s):
     # Should we make any of these raise informative errors?
     expected = {
         "__call__",
+        "__imatmul__",
         "__lshift__",
         "_deserialize",
         "_is_empty",
